/*
   render/draw.h
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#ifndef __INCLUDED_RENDER_DRAW_H__
#define __INCLUDED_RENDER_DRAW_H__

#include "core/gameinterface.h"

#include "math/axis.h"
#include "math/vector3f.h"

namespace render
{

/// reset lighting parameters
void pass_reset_lights();

/// draw the world
void draw(float seconds);

void draw_target(const core::Entity *entity);

/// reset
void reset();

/// draw a sphere
void draw_sphere(math::Color const & color, float radius);

/// draw mode lights and flares
void draw_model_lights(model::Model *model, const float scale,
	const math::Vector3f & entity_location, const math::Axis & entity_axis,
	const math::Color & entity_color, const float thrust, const float fuzz
);

/// draw a model
void draw_model_fragments(model::Model *model,
	const math::Color & color_primary, const math::Color & color_secondary,
	const float enginetime, const bool detail, const bool power, const float thrust
);

class Stats
{
public:
	static void clear();

	static size_t tris;
	static size_t quads;
	static size_t fragments;
};

}

#endif // __INCLUDED_RENDER_DRAW_H__

